==> xmlbuilder-0.0.1.tgz: 1289345865918-0.892756897257641/lib/XMLFragment.js <==
(function() {
  var XMLFragment;
  var __hasProp = Object.prototype.hasOwnProperty;
  XMLFragment = function(parent, name, attributes, text) {
    this.parent = parent;
    this.name = name || '';
    this.attributes = attributes || {};
    this.value = text || '';
    this.children = [];
    return this;
  };
  XMLFragment.prototype.val = {};
  XMLFragment.prototype.prolog = function(xmldec, doctype) {
    var _ref, att, child;
    if (this.value) {
      throw new Error("Text nodes cannot have child nodes");
    }
    if (!(typeof xmldec !== "undefined" && xmldec !== null) && !(typeof doctype !== "undefined" && doctype !== null)) {
      throw new Error("Either xmldec or doctype is required");
    }
    if ((typeof xmldec !== "undefined" && xmldec !== null) && !(typeof (_ref = xmldec.version) !== "undefined" && _ref !== null)) {
      throw new Error("Version number is required");
    }
    if ((typeof doctype !== "undefined" && doctype !== null) && !(typeof (_ref = doctype.name) !== "undefined" && _ref !== null)) {
      throw new Error("Dcument name is required");
    }
    if (typeof xmldec !== "undefined" && xmldec !== null) {
      if (!xmldec.version.match("^" + this.val.VersionNum + "$")) {
        throw new Error("Invalid version number: " + xmldec.version);
      }
      att = {
        version: xmldec.version
      };
      if (typeof (_ref = xmldec.encoding) !== "undefined" && _ref !== null) {
        if (!xmldec.encosing.match("^" + this.val.EncName + "$")) {
          throw new Error("Invalid encoding: " + xmldec.encoding);
        }
        att.encoding = xmldec.encoding;
      }
      if (xmldec.standalone) {
        att.standalone = xmldec.standalone ? "yes" : "no";
      }
      child = new XMLFragment(this, '?xml', att);
      this.children.push(child);
    }
    if (typeof doctype !== "undefined" && doctype !== null) {
      if (!doctype.name.match("^" + this.val.Name + "$")) {
        throw new Error("Invalid document name: " + doctype.name);
      }
      att = {
        name: doctype.name
      };
      if (typeof (_ref = doctype.ext) !== "undefined" && _ref !== null) {
        if (!doctype.ext.match("^" + this.val.ExternalID + "$")) {
          throw new Error("Invalid external ID: " + doctype.ext);
        }
        att.ext = doctype.ext;
      }
      child = new XMLFragment(this, '!DOCTYPE', att);
      this.children.push(child);
    }
    return child;
  };
  XMLFragment.prototype.element = function(name, attributes) {
    var child;
    if (this.value) {
      throw new Error("Text nodes cannot have child nodes");
    }
    if (!(typeof name !== "undefined" && name !== null)) {
      throw new Error("Missing element name");
    }
    if (!name.match("^" + this.val.Name + "$")) {
      throw new Error("Invalid element name: " + name);
    }
    child = new XMLFragment(this, name, attributes);
    this.children.push(child);
    return child;
  };
  XMLFragment.prototype.text = function(value) {
    var child;
    if (this.value) {
      throw new Error("Text nodes cannot have child nodes");
    }
    if (!(typeof value !== "undefined" && value !== null)) {
      throw new Error("Missing element text");
    }
    if (!value.match("^" + this.val.EntityValue + "$")) {
      throw new Error("Invalid element text: " + value);
    }
    child = new XMLFragment(this, '', {}, value);
    this.children.push(child);
    return child;
  };
  XMLFragment.prototype.up = function() {
    var _ref;
    if (!(typeof (_ref = this.parent) !== "undefined" && _ref !== null)) {
      throw new Error("This node has no parent");
    }
    return this.parent;
  };
  XMLFragment.prototype.attribute = function(name, value) {
    if (this.value) {
      throw new Error("Text nodes cannot have attributes");
    }
    if (!(typeof name !== "undefined" && name !== null)) {
      throw new Error("Missing attribute name");
    }
    if (!name.match("^" + this.val.Name + "$")) {
      throw new Error("Invalid attribute name: " + name);
    }
    if (!(typeof value !== "undefined" && value !== null)) {
      throw new Error("Missing attribute value");
    }
    if (!value.match("^" + this.val.AttValue + "$")) {
      throw new Error("Invalid attribute value: " + value);
    }
    this.attributes[name] = value;
    return this;
  };
  XMLFragment.prototype.toString = function(options, level) {
    var _i, _len, _ref, attName, attValue, child, indent, newline, pretty, r, space;
    pretty = (typeof options !== "undefined" && options !== null) && options.pretty || false;
    indent = (typeof options !== "undefined" && options !== null) && options.indent || '  ';
    newline = (typeof options !== "undefined" && options !== null) && options.newline || '\n';
    level || (level = 0);
    space = new Array(level + 1).join(indent);
    r = '';
    if (pretty) {
      r += space;
    }
    if (!this.value) {
      r += '<' + this.name;
    } else {
      r += this.value;
    }
    _ref = this.attributes;
    for (attName in _ref) {
      if (!__hasProp.call(_ref, attName)) continue;
      attValue = _ref[attName];
      if (this.name === '!DOCTYPE') {
        r += ' ' + attValue;
      } else {
        r += ' ' + attName + '="' + attValue + '"';
      }
    }
    if (this.children.length === 0) {
      if (!this.value) {
        r += (function() {
          if (this.name === '?xml') {
            return '?>';
          } else if (this.name === '!DOCTYPE') {
            return '>';
          } else {
            return '/>';
          }
        }).call(this);
      }
      if (pretty) {
        r += newline;
      }
    } else {
      r += '>';
      if (pretty) {
        r += newline;
      }
      _ref = this.children;
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        child = _ref[_i];
        r += child.toString(options, level + 1);
      }
      if (pretty) {
        r += space;
      }
      r += '</' + this.name + '>';
      if (pretty) {
        r += newline;
      }
    }
    return r;
  };
  XMLFragment.prototype.pro = function(xmldec, doctype) {
    return this.prolog(xmldec, doctype);
  };
  XMLFragment.prototype.ele = function(name, attributes) {
    return this.element(name, attributes);
  };
  XMLFragment.prototype.txt = function(value) {
    return this.text(value);
  };
  XMLFragment.prototype.att = function(name, value) {
    return this.attribute(name, value);
  };
  XMLFragment.prototype.p = function(xmldec, doctype) {
    return this.prolog(xmldec, doctype);
  };
  XMLFragment.prototype.e = function(name, attributes) {
    return this.element(name, attributes);
  };
  XMLFragment.prototype.t = function(value) {
    return this.text(value);
  };
  XMLFragment.prototype.a = function(name, value) {
    return this.attribute(name, value);
  };
  XMLFragment.prototype.u = function() {
    return this.up;
  };
  XMLFragment.prototype.val.Space = "(?:\u0020|\u0009|\u000D|\u000A)+";
  XMLFragment.prototype.val.Char = "\u0009|\u000A|\u000D|[\u0020-\uD7FF]|[\uE000-\uFFFD]";
  XMLFragment.prototype.val.NameStartChar = ":|[A-Z]|_|[a-z]|[\u00C0-\u00D6]|[\u00D8-\u00F6]|" + "[\u00F8-\u02FF]|[\u0370-\u037D]|[\u037F-\u1FFF]|[\u200C-\u200D]|[\u2070-\u218F]|" + "[\u2C00-\u2FEF]|[\u3001-\uD7FF]|[\uF900-\uFDCF]|[\uFDF0-\uFFFD]";
  XMLFragment.prototype.val.NameChar = ":|[A-Z]|_|[a-z]|[\u00C0-\u00D6]|[\u00D8-\u00F6]|[\u00F8-\u02FF]|" + "[\u0370-\u037D]|[\u037F-\u1FFF]|[\u200C-\u200D]|[\u2070-\u218F]|[\u2C00-\u2FEF]|" + "[\u3001-\uD7FF]|[\uF900-\uFDCF]|[\uFDF0-\uFFFD]" + "-|\.|[0-9]|\u00B7|[\u0300-\u036F]|[\u203F-\u2040]";
  XMLFragment.prototype.val.CharRef = "&#[0-9]+;|&#x[0-9a-fA-F]+;";
  XMLFragment.prototype.val.CharData = "(?![^<&]*]]>[^<&]*)[^<&]*";
  XMLFragment.prototype.val.Name = XMLFragment.prototype.val.NameStartChar + '(?:' + XMLFragment.prototype.val.NameChar + ')*';
  XMLFragment.prototype.val.NMToken = '(?:' + XMLFragment.prototype.val.NameChar + ')+';
  XMLFragment.prototype.val.EntityRef = '&' + XMLFragment.prototype.val.Name + ';';
  XMLFragment.prototype.val.Reference = '&' + XMLFragment.prototype.val.Name + ';' + '|' + XMLFragment.prototype.val.CharRef;
  XMLFragment.prototype.val.PEReference = '%' + XMLFragment.prototype.val.Name + ';';
  XMLFragment.prototype.val.EntityValue = '(?:[^%&"]|%' + XMLFragment.prototype.val.Name + ';|&' + XMLFragment.prototype.val.Name + ';)*';
  XMLFragment.prototype.val.AttValue = '(?:[^<&"]|' + XMLFragment.prototype.val.Reference + ')*';
  XMLFragment.prototype.val.SystemLiteral = '[^"]*';
  XMLFragment.prototype.val.PubIDChar = "\u0020|\u000D|\u000A|[a-zA-Z0-9]|[-'()+,./:=?;!*#@$_%]";
  XMLFragment.prototype.val.PubIDLiteral = '(?:' + XMLFragment.prototype.val.PubIDChar + ')*';
  XMLFragment.prototype.val.CommentChar = '(?!-)' + '(?:' + XMLFragment.prototype.val.Char + ')';
  XMLFragment.prototype.val.Comment = '<!--' + '(?:' + XMLFragment.prototype.val.CommentChar + '|' + '-' + XMLFragment.prototype.val.CommentChar + ')*' + '-->';
  XMLFragment.prototype.val.VersionNum = '1\.[0-9]+';
  XMLFragment.prototype.val.EncName = '[A-Za-z](?:[A-Za-z0-9\._]|-)*';
  XMLFragment.prototype.val.ExternalID = '(?:' + 'SYSTEM' + XMLFragment.prototype.val.Space + XMLFragment.prototype.val.SystemLiteral + ')|';
  '(?:' + 'PUBLIC' + XMLFragment.prototype.val.Space + XMLFragment.prototype.val.PubIDLateral + XMLFragment.prototype.val.Space + XMLFragment.prototype.val.SystemLiteral;
  module.exports = XMLFragment;
}).call(this);

==> xmlbuilder-0.0.2.tgz: 1289345866407-0.8558737009298056/lib/XMLFragment.js <==
(function() {
  var XMLFragment;
  var __hasProp = Object.prototype.hasOwnProperty;
  XMLFragment = function(parent, name, attributes, text) {
    this.parent = parent;
    this.name = name || '';
    this.attributes = attributes || {};
    this.value = text || '';
    this.children = [];
    return this;
  };
  XMLFragment.prototype.val = {};
  XMLFragment.prototype.prolog = function(xmldec, doctype) {
    var _ref, att, child;
    if (this.value) {
      throw new Error("Text nodes cannot have child nodes");
    }
    if (!(typeof xmldec !== "undefined" && xmldec !== null) && !(typeof doctype !== "undefined" && doctype !== null)) {
      throw new Error("Either xmldec or doctype is required");
    }
    if ((typeof xmldec !== "undefined" && xmldec !== null) && !(typeof (_ref = xmldec.version) !== "undefined" && _ref !== null)) {
      throw new Error("Version number is required");
    }
    if ((typeof doctype !== "undefined" && doctype !== null) && !(typeof (_ref = doctype.name) !== "undefined" && _ref !== null)) {
      throw new Error("Dcument name is required");
    }
    if (typeof xmldec !== "undefined" && xmldec !== null) {
      if (!String(xmldec.version).match("^" + this.val.VersionNum + "$")) {
        throw new Error("Invalid version number: " + xmldec.version);
      }
      att = {
        version: xmldec.version
      };
      if (typeof (_ref = xmldec.encoding) !== "undefined" && _ref !== null) {
        if (!String(xmldec.encoding).match("^" + this.val.EncName + "$")) {
          throw new Error("Invalid encoding: " + xmldec.encoding);
        }
        att.encoding = xmldec.encoding;
      }
      if (xmldec.standalone) {
        att.standalone = xmldec.standalone ? "yes" : "no";
      }
      child = new XMLFragment(this, '?xml', att);
      this.children.push(child);
    }
    if (typeof doctype !== "undefined" && doctype !== null) {
      if (!String(doctype.name).match("^" + this.val.Name + "$")) {
        throw new Error("Invalid document name: " + doctype.name);
      }
      att = {
        name: doctype.name
      };
      if (typeof (_ref = doctype.ext) !== "undefined" && _ref !== null) {
        if (!String(doctype.ext).match("^" + this.val.ExternalID + "$")) {
          throw new Error("Invalid external ID: " + doctype.ext);
        }
        att.ext = doctype.ext;
      }
      child = new XMLFragment(this, '!DOCTYPE', att);
      this.children.push(child);
    }
    return child;
  };
  XMLFragment.prototype.element = function(name, attributes) {
    var child;
    if (this.value) {
      throw new Error("Text nodes cannot have child nodes");
    }
    if (!(typeof name !== "undefined" && name !== null)) {
      throw new Error("Missing element name");
    }
    if (!String(name).match("^" + this.val.Name + "$")) {
      throw new Error("Invalid element name: " + name);
    }
    child = new XMLFragment(this, name, attributes);
    this.children.push(child);
    return child;
  };
  XMLFragment.prototype.text = function(value) {
    var child;
    if (this.value) {
      throw new Error("Text nodes cannot have child nodes");
    }
    if (!(typeof value !== "undefined" && value !== null)) {
      throw new Error("Missing element text");
    }
    if (!String(value).match("^" + this.val.EntityValue + "$")) {
      throw new Error("Invalid element text: " + value);
    }
    child = new XMLFragment(this, '', {}, value);
    this.children.push(child);
    return child;
  };
  XMLFragment.prototype.up = function() {
    var _ref;
    if (!(typeof (_ref = this.parent) !== "undefined" && _ref !== null)) {
      throw new Error("This node has no parent");
    }
    return this.parent;
  };
  XMLFragment.prototype.attribute = function(name, value) {
    if (this.value) {
      throw new Error("Text nodes cannot have attributes");
    }
    if (!(typeof name !== "undefined" && name !== null)) {
      throw new Error("Missing attribute name");
    }
    if (!String(name).match("^" + this.val.Name + "$")) {
      throw new Error("Invalid attribute name: " + name);
    }
    if (!(typeof value !== "undefined" && value !== null)) {
      throw new Error("Missing attribute value");
    }
    if (!String(value).match("^" + this.val.AttValue + "$")) {
      throw new Error("Invalid attribute value: " + value);
    }
    this.attributes[name] = value;
    return this;
  };
  XMLFragment.prototype.toString = function(options, level) {
    var _i, _len, _ref, attName, attValue, child, indent, newline, pretty, r, space;
    pretty = (typeof options !== "undefined" && options !== null) && options.pretty || false;
    indent = (typeof options !== "undefined" && options !== null) && options.indent || '  ';
    newline = (typeof options !== "undefined" && options !== null) && options.newline || '\n';
    level || (level = 0);
    space = new Array(level + 1).join(indent);
    r = '';
    if (pretty) {
      r += space;
    }
    if (!this.value) {
      r += '<' + this.name;
    } else {
      r += this.value;
    }
    _ref = this.attributes;
    for (attName in _ref) {
      if (!__hasProp.call(_ref, attName)) continue;
      attValue = _ref[attName];
      if (this.name === '!DOCTYPE') {
        r += ' ' + attValue;
      } else {
        r += ' ' + attName + '="' + attValue + '"';
      }
    }
    if (this.children.length === 0) {
      if (!this.value) {
        r += (function() {
          if (this.name === '?xml') {
            return '?>';
          } else if (this.name === '!DOCTYPE') {
            return '>';
          } else {
            return '/>';
          }
        }).call(this);
      }
      if (pretty) {
        r += newline;
      }
    } else {
      r += '>';
      if (pretty) {
        r += newline;
      }
      _ref = this.children;
      for (_i = 0, _len = _ref.length; _i < _len; _i++) {
        child = _ref[_i];
        r += child.toString(options, level + 1);
      }
      if (pretty) {
        r += space;
      }
      r += '</' + this.name + '>';
      if (pretty) {
        r += newline;
      }
    }
    return r;
  };
  XMLFragment.prototype.pro = function(xmldec, doctype) {
    return this.prolog(xmldec, doctype);
  };
  XMLFragment.prototype.ele = function(name, attributes) {
    return this.element(name, attributes);
  };
  XMLFragment.prototype.txt = function(value) {
    return this.text(value);
  };
  XMLFragment.prototype.att = function(name, value) {
    return this.attribute(name, value);
  };
  XMLFragment.prototype.p = function(xmldec, doctype) {
    return this.prolog(xmldec, doctype);
  };
  XMLFragment.prototype.e = function(name, attributes) {
    return this.element(name, attributes);
  };
  XMLFragment.prototype.t = function(value) {
    return this.text(value);
  };
  XMLFragment.prototype.a = function(name, value) {
    return this.attribute(name, value);
  };
  XMLFragment.prototype.u = function() {
    return this.up;
  };
  XMLFragment.prototype.val.Space = "(?:\u0020|\u0009|\u000D|\u000A)+";
  XMLFragment.prototype.val.Char = "\u0009|\u000A|\u000D|[\u0020-\uD7FF]|[\uE000-\uFFFD]";
  XMLFragment.prototype.val.NameStartChar = ":|[A-Z]|_|[a-z]|[\u00C0-\u00D6]|[\u00D8-\u00F6]|" + "[\u00F8-\u02FF]|[\u0370-\u037D]|[\u037F-\u1FFF]|[\u200C-\u200D]|[\u2070-\u218F]|" + "[\u2C00-\u2FEF]|[\u3001-\uD7FF]|[\uF900-\uFDCF]|[\uFDF0-\uFFFD]";
  XMLFragment.prototype.val.NameChar = ":|[A-Z]|_|[a-z]|[\u00C0-\u00D6]|[\u00D8-\u00F6]|[\u00F8-\u02FF]|" + "[\u0370-\u037D]|[\u037F-\u1FFF]|[\u200C-\u200D]|[\u2070-\u218F]|[\u2C00-\u2FEF]|" + "[\u3001-\uD7FF]|[\uF900-\uFDCF]|[\uFDF0-\uFFFD]" + "-|\.|[0-9]|\u00B7|[\u0300-\u036F]|[\u203F-\u2040]";
  XMLFragment.prototype.val.CharRef = "&#[0-9]+;|&#x[0-9a-fA-F]+;";
  XMLFragment.prototype.val.CharData = "(?![^<&]*]]>[^<&]*)[^<&]*";
  XMLFragment.prototype.val.Name = XMLFragment.prototype.val.NameStartChar + '(?:' + XMLFragment.prototype.val.NameChar + ')*';
  XMLFragment.prototype.val.NMToken = '(?:' + XMLFragment.prototype.val.NameChar + ')+';
  XMLFragment.prototype.val.EntityRef = '&' + XMLFragment.prototype.val.Name + ';';
  XMLFragment.prototype.val.Reference = '&' + XMLFragment.prototype.val.Name + ';' + '|' + XMLFragment.prototype.val.CharRef;
  XMLFragment.prototype.val.PEReference = '%' + XMLFragment.prototype.val.Name + ';';
  XMLFragment.prototype.val.EntityValue = '(?:[^%&"]|%' + XMLFragment.prototype.val.Name + ';|&' + XMLFragment.prototype.val.Name + ';)*';
  XMLFragment.prototype.val.AttValue = '(?:[^<&"]|' + XMLFragment.prototype.val.Reference + ')*';
  XMLFragment.prototype.val.SystemLiteral = '[^"]*';
  XMLFragment.prototype.val.PubIDChar = "\u0020|\u000D|\u000A|[a-zA-Z0-9]|[-'()+,./:=?;!*#@$_%]";
  XMLFragment.prototype.val.PubIDLiteral = '(?:' + XMLFragment.prototype.val.PubIDChar + ')*';
  XMLFragment.prototype.val.CommentChar = '(?!-)' + '(?:' + XMLFragment.prototype.val.Char + ')';
  XMLFragment.prototype.val.Comment = '<!--' + '(?:' + XMLFragment.prototype.val.CommentChar + '|' + '-' + XMLFragment.prototype.val.CommentChar + ')*' + '-->';
  XMLFragment.prototype.val.VersionNum = '1\.[0-9]+';
  XMLFragment.prototype.val.EncName = '[A-Za-z](?:[A-Za-z0-9\._]|-)*';
  XMLFragment.prototype.val.ExternalID = '(?:' + 'SYSTEM' + XMLFragment.prototype.val.Space + XMLFragment.prototype.val.SystemLiteral + ')|';
  '(?:' + 'PUBLIC' + XMLFragment.prototype.val.Space + XMLFragment.prototype.val.PubIDLateral + XMLFragment.prototype.val.Space + XMLFragment.prototype.val.SystemLiteral;
  module.exports = XMLFragment;
}).call(this);
